PyMP
====

A Pythonic Implementation of Greedy Algorithms developed during my PhD

This software is provided under GNU GPL license see Licence.txt

Documentation: http://manuel.moussallam.net/PyMP/

Install, build or test with make utility: 

>>> make install

or using:

>>> python setup.py install

version: 1.1
Author: Manuel Moussallam
contact: first.last -at- gmail.com
contributors: A. Gramfort
